ComplexPackingStrategy

Enum ComplexPackingStrategy 

pub enum ComplexPackingStrategy {
    LookAhead(usize),
}
Strategies applied when performing complex packing on numerical sequences. Complex packing is a method that divides a sequence of numbers into groups and efficiently compresses each group to improve the overall compression ratio of the data.

Variants



LookAhead(usize)

A strategy that pre-reads a specified number of elements to determine whether to add an element to the current group.