FixedSurface

Struct FixedSurface 

pub struct FixedSurface {
    pub surface_type: u8,
    pub scale_factor: i8,
    pub scaled_value: i32,
}

Fields

surface_type: u8

Use CodeTable4_5 to get textual representation.

scale_factor: i8scaled_value: i32

Implementations

Source

impl FixedSurface

pub fn new(surface_type: u8, scale_factor: i8, scaled_value: i32) -> Self

pub fn value(&self) -> f64

pub fn unit(&self) -> Option<&str>

Returns the unit string defined for the type of the surface, if any.

Examples
assert_eq!(grib::FixedSurface::new(100, 0, 0).unit(), Some("Pa"));
pub fn scale_factor_is_nan(&self) -> bool

Checks if the scale factor should be treated as missing.

pub fn value_is_nan(&self) -> bool

Checks if the scaled value should be treated as missing.

pub fn describe(&self) -> (String, String, String)