pub trait LatLons {
type Iter<'a>: Iterator<Item = (f32, f32)>
where Self: 'a;
// Required method
fn latlons_unchecked<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>;
// Provided method
fn latlons<'a>(
&'a self,
) -> Result<Map<Self::Iter<'a>, fn((f32, f32)) -> (f32, f32)>, GribError> { ... }
}Expand description
A functionality to generate an iterator over latitude/longitude of grid points.
Required Associated Types
Required Methods
Sourcefn latlons_unchecked<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
fn latlons_unchecked<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
Computes and returns an iterator over latitudes and longitudes of grid
points in degrees. Unlike the return values from LatLons::latlons,
the longitude values from thie method do not necessarily fall within
the range [-180°, 180°].
Provided Methods
Sourcefn latlons<'a>(
&'a self,
) -> Result<Map<Self::Iter<'a>, fn((f32, f32)) -> (f32, f32)>, GribError>
fn latlons<'a>( &'a self, ) -> Result<Map<Self::Iter<'a>, fn((f32, f32)) -> (f32, f32)>, GribError>
Computes and returns an iterator over latitudes and longitudes of grid
points in degrees. The returned longitude values are converted to fall
within the range [-180°, 180°].
The order of lat/lon data of grid points is the same as the order of the
grid point values, defined by the scanning mode
(ScanningMode) in the data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl LatLons for GridDefinitionTemplateValues
impl LatLons for GridDefinitionTemplateValues
type Iter<'a> = GridPointLatLons where Self: 'a
Sourceimpl LatLons for Template3_1
impl LatLons for Template3_1
Sourceimpl LatLons for Template3_20
Available on crate feature gridpoints-proj only.
impl LatLons for Template3_20
gridpoints-proj only.Sourceimpl LatLons for Template3_30
Available on crate feature gridpoints-proj only.
impl LatLons for Template3_30
gridpoints-proj only.