WriteGrib2DataSections

Trait WriteGrib2DataSections 

pub trait WriteGrib2DataSections {
    // Required methods
    fn section5_len(&self) -> usize;
    fn write_section5(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
    fn section6_len(&self) -> usize;
    fn write_section6(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
    fn section7_len(&self) -> usize;
    fn write_section7(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
}
A serializer that writes the byte sequence of sections concerning GPV data to the output buffer.

Required Methods

fn section5_len(&self) -> usize

Returns the length of the byte sequence in Section 5.

fn write_section5(&self, buf: &mut [u8]) -> Result<usize, &'static str>

Writes the byte sequence of Section 5 to the output buffer.

fn section6_len(&self) -> usize

Returns the length of the byte sequence in Section 6.

fn write_section6(&self, buf: &mut [u8]) -> Result<usize, &'static str>

Writes the byte sequence of Section 6 to the output buffer.

fn section7_len(&self) -> usize

Returns the length of the byte sequence in Section 7.

fn write_section7(&self, buf: &mut [u8]) -> Result<usize, &'static str>

Writes the byte sequence of Section 7 to the output buffer.

Implementors