GridShortName

Trait GridShortName 

pub trait GridShortName {
    // Required method
    fn short_name(&self) -> &'static str;
}
A functionality to return a short name of the grid system.

Required Methods

fn short_name(&self) -> &'static str

Returns the grid type.

The grid types are denoted as short strings based on gridType used in ecCodes.

This is provided primarily for debugging and simple notation purposes. It is better to use enum variants instead of the string notation to determine the grid type.

Implementors