LatLons

Trait LatLons 

pub trait LatLons {
    type Iter<'a>: Iterator<Item = (f32, f32)>
       where Self: 'a;

    // Required method
    fn latlons<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>;
}
A functionality to generate an iterator over latitude/longitude of grid points.

Required Associated Types

type Iter<'a>: Iterator<Item = (f32, f32)> where Self: 'a

Required Methods

fn latlons<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>

Computes and returns an iterator over latitudes and longitudes of grid points in degrees.

The order of lat/lon data of grid points is the same as the order of the grid point values, defined by the scanning mode (ScanningMode) in the data.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl LatLons for GridDefinitionTemplateValues

Source

type Iter<'a> = GridPointLatLons where Self: 'a

Source

impl LatLons for GaussianGrid

Source

type Iter<'a> = RegularGridIterator

Source

impl LatLons for LatLonGrid

Source

type Iter<'a> = RegularGridIterator

Source

impl LatLons for Template3_1

Source

type Iter<'a> = Unrotate<RegularGridIterator> where Self: 'a

Source

impl LatLons for Template3_20

Available on crate feature gridpoints-proj only.
Source

type Iter<'a> = IntoIter<(f32, f32)> where Self: 'a

Source

impl LatLons for Template3_30

Available on crate feature gridpoints-proj only.
Source

type Iter<'a> = IntoIter<(f32, f32)>

Source

impl<'s, R> LatLons for SubMessage<'s, R>

Source

type Iter<'a> = GridPointLatLons where Self: 'a