pub trait LatLons {
type Iter<'a>: Iterator<Item = (f32, f32)>
where Self: 'a;
// Required method
fn latlons<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>;
}Expand description
A functionality to generate an iterator over latitude/longitude of grid points.
Required Associated Types
Required Methods
Sourcefn latlons<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
fn latlons<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
Computes and returns an iterator over latitudes and longitudes of grid points in degrees.
The order of lat/lon data of grid points is the same as the order of the
grid point values, defined by the scanning mode
(ScanningMode) in the data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl LatLons for GridDefinitionTemplateValues
impl LatLons for GridDefinitionTemplateValues
type Iter<'a> = GridPointLatLons where Self: 'a
Sourceimpl LatLons for Template3_1
impl LatLons for Template3_1
Sourceimpl LatLons for Template3_20
Available on crate feature gridpoints-proj only.
impl LatLons for Template3_20
Available on crate feature
gridpoints-proj only.Sourceimpl LatLons for Template3_30
Available on crate feature gridpoints-proj only.
impl LatLons for Template3_30
Available on crate feature
gridpoints-proj only.