pub trait WriteGrib2DataSections {
// Required methods
fn section5_len(&self) -> usize;
fn write_section5(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
fn section6_len(&self) -> usize;
fn write_section6(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
fn section7_len(&self) -> usize;
fn write_section7(&self, buf: &mut [u8]) -> Result<usize, &'static str>;
}Expand description
A serializer that writes the byte sequence of sections concerning GPV data to the output buffer.
Required Methods
Sourcefn section5_len(&self) -> usize
fn section5_len(&self) -> usize
Returns the length of the byte sequence in Section 5.
Sourcefn write_section5(&self, buf: &mut [u8]) -> Result<usize, &'static str>
fn write_section5(&self, buf: &mut [u8]) -> Result<usize, &'static str>
Writes the byte sequence of Section 5 to the output buffer.
Sourcefn section6_len(&self) -> usize
fn section6_len(&self) -> usize
Returns the length of the byte sequence in Section 6.
Sourcefn write_section6(&self, buf: &mut [u8]) -> Result<usize, &'static str>
fn write_section6(&self, buf: &mut [u8]) -> Result<usize, &'static str>
Writes the byte sequence of Section 6 to the output buffer.
Sourcefn section7_len(&self) -> usize
fn section7_len(&self) -> usize
Returns the length of the byte sequence in Section 7.